@@ -6,6 +6,7 @@ Deploy a GCE machine with the informed params
 
 from googleapiclient import discovery
 from googleapiclient.errors import HttpError
+from google.auth.exceptions import TransportError
 
 from gcpinfra.gcp.conf import GCPConf
 from gcpinfra.gce.conf import GCEMachine
@@ -22,7 +23,7 @@ class GCEMachineDeployer:
     """
 
     def __init__(self, name, zone, machine, docker_image, env=None,
-                 restart_policy='Always'):
+                 restart_policy='Always', subnetwork=None, external_ip=True):
         """Constructor."""
 
         self.conf = GCPConf()
@@ -37,6 +38,8 @@ class GCEMachineDeployer:
         self.status_rep = None
         self.status = None
         self.was_instantiated = False
+        self.subnetwork = 'default' if subnetwork is None else subnetwork
+        self.external_ip = external_ip
 
         if self.restart_policy not in ['OnFailure', 'Never', 'Always']:
             raise ValueError("Invalid 'restart_policy' value")
@@ -61,6 +64,9 @@ class GCEMachineDeployer:
             except HttpError as e:
                 if int(e.resp['status']) == 500:
                     continue
+            except TransportError:
+                continue
+
             break
 
     def __get_region(self):
@@ -95,7 +101,9 @@ class GCEMachineDeployer:
                 self.was_instantiated = True
         except HttpError as e:
             if int(e.resp['status']) == 500:
-                self.instantiate()  # tenta novamente em caso de erro 500
+                self.instantiate()  # try again in case of error 500
+        except TransportError:
+            self.instantiate()
 
     def get(self):
         """Get updated representation."""
@@ -112,7 +120,9 @@ class GCEMachineDeployer:
             if self.was_instantiated and int(e.resp['status']) == 404:
                 self.status = 'DELETED'
             elif int(e.resp['status']) == 500:
-                self.get()  # tenta novamente em caso de erro 500
+                self.get()  # try again in case of error 500
+        except TransportError:
+            self.get()
 
     def mount_representation(self):
         """Mount this object representation."""
@@ -148,7 +158,7 @@ class GCEMachineDeployer:
                     'deviceName': self.name,
                     'initializeParams': {
                         'sourceImage': ('projects/cos-cloud/global/images/'
-                                        'cos-stable-80-12739-91-0'),
+                                        'cos-stable-85-13310-1041-38'),
                         'diskType': 'projects/{}/zones/{}/diskTypes/{}'.format(
                             self.conf.project_id, self.zone,
                             self.machine.disk_config.boot_disk_type),
@@ -162,21 +172,13 @@ class GCEMachineDeployer:
             'networkInterfaces': [
                 {
                     'kind': 'compute#networkInterface',
-                    'subnetwork': 'projects/{}/regions/{}/subnetworks/default'.format(
-                        self.conf.project_id, self.region),
-                    'accessConfigs': [
-                        {
-                            'kind': 'compute#accessConfig',
-                            'name': 'External NAT',
-                            'type': 'ONE_TO_ONE_NAT',
-                            'networkTier': 'PREMIUM'
-                        }
-                    ],
+                    'subnetwork': 'projects/{}/regions/{}/subnetworks/{}'.format(
+                        self.conf.project_id, self.region, self.subnetwork),
                     'aliasIpRanges': []
                 }
             ],
             'description': '',
-            'labels': {'container-vm': 'cos-stable-80-12739-91-0'},
+            'labels': {'container-vm': 'cos-stable-85-13310-1041-38'},
             'scheduling': {
                 'preemptible': False,
                 'onHostMaintenance': 'MIGRATE',
@@ -197,4 +199,12 @@ class GCEMachineDeployer:
                 'enableIntegrityMonitoring': True
             }
         }
+
+        if self.external_ip:
+            _rep['networkInterfaces'][0].update(
+                {'accessConfigs': [{'kind': 'compute#accessConfig',
+                    'name': 'External NAT',
+                    'type': 'ONE_TO_ONE_NAT',
+                    'networkTier': 'PREMIUM'}]})
+
         return _rep
